package com.mockobjects.sql;

import java.sql.SQLException;
import java.sql.ResultSet;
import java.sql.ParameterMetaData;
import java.net.URL;

public class MockPreparedStatement extends CommonMockPreparedStatement {
    public boolean getMoreResults(int current) throws SQLException {
        notImplemented();
        return false;
    }

    public void setURL(int parameterIndex, URL x) throws SQLException {
        notImplemented();
    }

    public ResultSet getGeneratedKeys() throws SQLException {
        notImplemented();
        return null;
    }

    public ParameterMetaData getParameterMetaData() throws SQLException {
        notImplemented();
        return null;
    }

    public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
        notImplemented();
        return 0;
    }

    public int executeUpdate(String sql, int columnIndexes[]) throws SQLException {
        notImplemented();
        return 0;
    }

    public int executeUpdate(String sql, String columnNames[]) throws SQLException {
        notImplemented();
        return 0;
    }

    public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
        notImplemented();
        return false;
    }

    public boolean execute(String sql, int columnIndexes[]) throws SQLException {
        notImplemented();
        return false;
    }

    public boolean execute(String sql, String columnNames[]) throws SQLException {
        notImplemented();
        return false;
    }

    public int getResultSetHoldability() throws SQLException {
        notImplemented();
        return 0;
    }
}
